@@ -5,6 +5,7 @@ from .heatmap import HeatmapLayer
 from .faults import FaultLayer
 from .stations import StationLayer
 from .epicentral_circles import EpicentralCirclesLayer
+from .site_marker import SiteMarkerLayer
 
 __all__ = [
     "EventMarkerLayer",
@@ -13,4 +14,5 @@ __all__ = [
     "FaultLayer",
     "StationLayer",
     "EpicentralCirclesLayer",
+    "SiteMarkerLayer",
 ]
