@@ -8,6 +8,6 @@ class MapLayer(abc.ABC):
     """Abstract base class for all map layers."""
 
     @abc.abstractmethod
-    def to_feature_group(self) -> folium.FeatureGroup:
+    def toFeatureGroup(self) -> folium.FeatureGroup:
         """Return a Folium FeatureGroup ready to be added to a map."""
         raise NotImplementedError
