@@ -13,7 +13,7 @@ class EpicentralCirclesLayer(MapLayer):
         self.n = max(1, n_circles)
         self.show = show
 
-    def to_feature_group(self) -> folium.FeatureGroup:
+    def toFeatureGroup(self) -> folium.FeatureGroup:
         fg = folium.FeatureGroup(name="Epicentral circles", show=self.show)
         step = self.radius / self.n
         for i in range(1, self.n + 1):
