@@ -12,7 +12,7 @@ class FaultLayer(MapLayer):
         self.weight = weight
         self.show = show
 
-    def to_feature_group(self) -> folium.FeatureGroup:
+    def toFeatureGroup(self) -> folium.FeatureGroup:
         style = {"color": self.color, "weight": self.weight, "opacity": 1.0}
         fg = folium.FeatureGroup(name="Faults", show=self.show)
         folium.GeoJson(data=self.gdf, style_function=lambda _: style).add_to(fg)
