@@ -26,7 +26,7 @@ class HeatmapLayer(MapLayer):
         self.min_opacity = min_opacity
         self.show = show
 
-    def to_feature_group(self) -> folium.FeatureGroup:
+    def toFeatureGroup(self) -> folium.FeatureGroup:
         fg = folium.FeatureGroup(name="Heatmap", show=self.show)
         data = [
             (r["latitude"], r["longitude"], r[self.mag_col])
