@@ -14,7 +14,7 @@ class SiteMarkerLayer:
         self.project = project
         self.client = client
 
-    def to_feature_group(self) -> folium.FeatureGroup:
+    def toFeatureGroup(self) -> folium.FeatureGroup:
         fg = folium.FeatureGroup(name="Site", show=True)
 
         popup = folium.Popup(
