@@ -16,7 +16,7 @@ class StationLayer(MapLayer):
         self.df = stations_df
         self.show = show
 
-    def to_feature_group(self) -> folium.FeatureGroup:
+    def toFeatureGroup(self) -> folium.FeatureGroup:
         fg = folium.FeatureGroup(name="Stations", show=self.show)
         for _, r in self.df.iterrows():
             color, icon = _ICON.get(int(r.get("axes", 0)), ("gray", "info-sign"))
